lanscanner
=======
lanscanner is an automatic network scanner.
this tool lists all the interfaces for you. after chossing, all active IPs in the network are detected and then shows all open ports for each ip.


usage
=======


installation:

    pip install lanscanner

run:

    python3 -m scanner
